import codecs
import os
import re

from setuptools import setup, find_packages


def readme():
    with open('README.rst') as f:
        return f.read()


here = os.path.abspath(os.path.dirname(__file__))


def read(*parts):
    with codecs.open(os.path.join(here, *parts), 'r') as fp:
        return fp.read()


def find_version(*file_paths):
    version_file = read(*file_paths)
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                              version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string. [{}]".format(file_paths))


setup(
    name='minilite',
    version=find_version("minilite/__version__.py"),
    description='Mini CLI-Tool for sqlite',
    long_description=readme(),
    classifiers=[
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    keywords='sqlite cli',
    url='http://mathcoach.htwsaar.de/',
    author='Hong-Phuc Bui',
    author_email='hong-phuc.bui@htwsaar.de',
    license='MIT',
    packages=find_packages(exclude=["docs", "build", "tests"]),
    package_data={
        'minilite': ['*.sql']
    },
    data_files=[

    ],
    install_requires=[

    ],
    tests_require=['pytest', 'pytest-runner', 'pytest-cov'],
    setup_requires=["pytest-runner"],
    entry_points={

    },
    include_package_data=True,
    zip_safe=False
)
